@@ -3,7 +3,7 @@
 BigInt BigInt::clearBit(size_t index) const
 {
     BigInt ret(*this);
-    BN_clear_bit(&ret.d_bn, index);
+    BN_clear_bit(ret.d_bn, index);
     return ret;
 }
 
