@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::maskBitsc(size_t lowerNBits) const
+BigInt BigInt::maskBitsc(size_t lowerNBits) const
 {
     BigInt ret(*this);
     ret.maskBits(lowerNBits);
