@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::operator-() const
+BigInt BigInt::operator-() const
 {
     BigInt tmp(*this);
     tmp.negate();
