@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::tildeIntc() const
+BigInt BigInt::tildeIntc() const
 {
     BigInt ret(*this);
     ret.tildeInt();
