@@ -1,7 +1,7 @@
 #include <iostream>
 #include <iterator>
 
-#include <bobcat/errno>
+#include <bobcat/exception>
 #ifdef BOBCAT
     #include <bobcat/configfile>
 #else
@@ -30,9 +30,9 @@ try
     
     cf.open(argv[1]);
 
-    cout << "opened again: " << argv[1] << '\n';
-    cout << "Got " << cf.size() << " lines\n";
-    cout << cf[0] << " from line " << cf.index(0) << "\n";
+    cout << "opened again: " << argv[1] << "\n"
+    cout << "Got " << cf.size() << " lines\n" <<
+    cout << cf[0] << " from line " << cf.index(0) << "\n"
     cout << "================\n";
 
     copy(cf.begin(), cf.end(), ostream_iterator<string>(cout, "\n"));
@@ -87,9 +87,9 @@ try
         cout << "value of findKey: " << cf.findKey(param) << '\n';
     }
 }
-catch (Errno e)
+catch (exception const &e)
 {
-    cout << "Fatal: " << e.why() << endl;
+    cout << "Fatal: " << e.what() << endl;
     return 1;
 }
 
