@@ -14,7 +14,7 @@ DigestBuf::DigestBuf(char const *type, size_t bufsize)
             if (type == 0)
                 type = "** unspecified digest type **";
     
-            throw Exception(1) << "DigestBuf `" << type << "' not available";
+            throw Exception{1} << "DigestBuf `" << type << "' not available";
         }
         d_pimpl->buffer = new char[bufsize];
         open();
