@@ -2,12 +2,12 @@
 
 void EncryptBuf::installKey(string const &key, size_t numberOfBytes)
 {
-    EVP_CIPHER_CTX_set_key_length(&d_pimpl->ctx, numberOfBytes);
+    EVP_CIPHER_CTX_set_key_length(d_pimpl->ctx, numberOfBytes);
 
     if 
     (
-        !EVP_EncryptInit_ex(&d_pimpl->ctx, 0, 0,
+        not EVP_EncryptInit_ex(d_pimpl->ctx, 0, 0,
             reinterpret_cast<unsigned char const *>(key.data()), 0)
     )
-        throw Errno(1, "Couldn't set Key");
+        throw Exception{1} << "Couldn't set Key";
 }
