@@ -8,11 +8,9 @@ using namespace FBB;
 
 int main()
 {
-    LogBuffer buffer(cout);
+    LogBuffer buffer(cout, FBB::TIMESTAMPS);
     ostream log(&buffer);
 
     log << "This message is written to cout" << nl <<
            setw(16) << ' ' << "occupying multiple lines\n";
-
-    return 0;
 }
