@@ -5,7 +5,8 @@ int Randbuffer::underflow()
     ostringstream ostr;
 
     ostr << d_min + 
-            static_cast<int>((d_max - d_min) * (rand() / (RAND_MAX + 1.0))) << 
+            static_cast<int>((d_max - d_min) * 
+                                (random() / (RAND_MAX + 1.0))) << 
             " ";        
 
     size_t n = ostr.str().length();
@@ -16,5 +17,5 @@ int Randbuffer::underflow()
     ostr.str().copy(cp, string::npos);
     setg(cp, cp, cp + n);
 
-    return *gptr();
+    return static_cast<unsigned char>(*gptr());
 }
