@@ -21,7 +21,7 @@ char *ReadLineBuf::expandLine()
         break;
 
         default:
-            swap(expanded, buf);
+            std::swap(expanded, buf);
         break;
     }
     free(expanded);
