@@ -2,7 +2,7 @@
 
 User &User::operator=(User &&tmp)
 {
-    fswap(*this, tmp);
+    fswap(*this, tmp, d_name, d_password, d_realname, d_homedir, d_shell);
     return *this;
 }
 
